@@ -20,4 +20,4 @@ except PackageNotFoundError:  # pragma: no cover
     warnings.warn("can not read __version__, assuming local test context, setting it to ?.?.?")
     __version__ = "?.?.?"
 
-from .changelogfactory import ChangeLogFormater
+from .changelogfactory import ChangeLogFactory, ChangeLogFormaterRecordType, ChangeLogFormater
